@@ -1,6 +1,6 @@
 from typing import TypedDict, Optional, Literal, List
 
-from method.resource import Resource
+from method.resource import MethodResponse, Resource
 from method.configuration import Configuration
 from method.errors import ResourceError
 
@@ -29,8 +29,8 @@ class AccountCardBrandsResource(Resource):
     def __init__(self, config: Configuration):
         super(AccountCardBrandsResource, self).__init__(config.add_path('card_brands'))
 
-    def retrieve(self, crbd_id: str) -> AccountCardBrand:
+    def retrieve(self, crbd_id: str) -> MethodResponse[AccountCardBrand]:
         return super(AccountCardBrandsResource, self)._get_with_id(crbd_id)
     
-    def create(self) -> AccountCardBrand:
+    def create(self) -> MethodResponse[AccountCardBrand]:
         return super(AccountCardBrandsResource, self)._create({})
